==> haskell-dependent-map-0.4.0.0-288-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-map
version:              0.4.0.0
visibility:           public
id:                   dependent-map-0.4.0.0-ILspeOrHNCt9FIafb6H2AA
key:                  dependent-map-0.4.0.0-ILspeOrHNCt9FIafb6H2AA
license:              LicenseRef-OtherLicense
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-map
synopsis:             Dependent finite maps (partial dependent products)
description:
    Provides a type called @DMap@ which generalizes
    @Data.Map.Map@, allowing keys to specify the type
    of value that can be associated with them.

category:             Data, Dependent Types
abi:                  46b2471575e63fb11c452fb8ce06221b
exposed:              True
exposed-modules:
    Data.Dependent.Map Data.Dependent.Map.Internal
    Data.Dependent.Map.Lens

hidden-modules:       Data.Dependent.Map.PtrEquality
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-map
hs-libraries:         HSdependent-map-0.4.0.0-ILspeOrHNCt9FIafb6H2AA
depends:
    base-4.17.2.1 constraints-extras-0.4.0.1-G1r9CAFXHQJJYurs9ekYA4
    containers-0.6.7 dependent-sum-0.7.2.0-IcaTIiBFfBHGFQEE4mGcgC

haddock-interfaces:
    /usr/share/doc/haskell-dependent-map/html/dependent-map.haddock

haddock-html:         /usr/share/doc/haskell-dependent-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-map-0.4.0.0-292-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-map
version:              0.4.0.0
visibility:           public
id:                   dependent-map-0.4.0.0-2enZRZSSwZYFXKDSBObC9R
key:                  dependent-map-0.4.0.0-2enZRZSSwZYFXKDSBObC9R
license:              LicenseRef-OtherLicense
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-map
synopsis:             Dependent finite maps (partial dependent products)
description:
    Provides a type called @DMap@ which generalizes
    @Data.Map.Map@, allowing keys to specify the type
    of value that can be associated with them.

category:             Data, Dependent Types
abi:                  2637e1d065c39261b4beb76963554815
exposed:              True
exposed-modules:
    Data.Dependent.Map Data.Dependent.Map.Internal
    Data.Dependent.Map.Lens

hidden-modules:       Data.Dependent.Map.PtrEquality
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dependent-map-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-map
hs-libraries:         HSdependent-map-0.4.0.0-2enZRZSSwZYFXKDSBObC9R
depends:
    base-4.17.2.1 constraints-extras-0.4.0.1-9IE8yze3riREnRRfTFAhed
    containers-0.6.7 dependent-sum-0.7.2.0-I5EpE5cXB02LHSMs4K2XcM

haddock-interfaces:
    /usr/share/doc/haskell-dependent-map/html/dependent-map.haddock

haddock-html:         /usr/share/doc/haskell-dependent-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
